@@ -33,7 +33,7 @@ var group__spa__node =
       [ "target_rate", "structspa__io__clock.html#a02274245ac560717fc5c06ddc66553ff", null ],
       [ "target_duration", "structspa__io__clock.html#ad5f6c0254efd87a20ca5807b577d3473", null ],
       [ "target_seq", "structspa__io__clock.html#af91526e984d8c9453e8b98c12dd1f500", null ],
-      [ "padding", "structspa__io__clock.html#add07660ad1ad6f6951596c5a0422cd9b", null ],
+      [ "cycle", "structspa__io__clock.html#a4fae975c36d6534e368ef396961b23b9", null ],
       [ "xrun", "structspa__io__clock.html#a3dc77892eea443b66c01d2acc91acaeb", null ]
     ] ],
     [ "spa_io_video_size", "structspa__io__video__size.html", [
@@ -58,7 +58,9 @@ var group__spa__node =
       [ "signature_denom", "structspa__io__segment__bar.html#a65f1a61b7161bc2ddfb12e2bec1c51d3", null ],
       [ "bpm", "structspa__io__segment__bar.html#a5398027b6c636c287b2df47239b6b9e3", null ],
       [ "beat", "structspa__io__segment__bar.html#a212f71e2e8b5587d48f4a71151ebdda5", null ],
-      [ "padding", "structspa__io__segment__bar.html#a23933e48afa26296c4b2c2df6470bb12", null ]
+      [ "bar_start_tick", "structspa__io__segment__bar.html#ad1c1cb6cda52db4b3ffbb4dbee804bb0", null ],
+      [ "ticks_per_beat", "structspa__io__segment__bar.html#a7c4acf7c0d30df734669355189d0879f", null ],
+      [ "padding", "structspa__io__segment__bar.html#a34df6bc077aed465af23d8b5b8d74a85", null ]
     ] ],
     [ "spa_io_segment_video", "structspa__io__segment__video.html", [
       [ "flags", "structspa__io__segment__video.html#abb72f2853693bb3cfad27520b41f3248", null ],
@@ -95,6 +97,9 @@ var group__spa__node =
       [ "flags", "structspa__io__rate__match.html#a7b89f4c442e2856faf64abeec186050e", null ],
       [ "padding", "structspa__io__rate__match.html#a2ef8495597b9368305657a6202944046", null ]
     ] ],
+    [ "spa_io_async_buffers", "structspa__io__async__buffers.html", [
+      [ "buffers", "structspa__io__async__buffers.html#a97004192f552cb50fee39067e5b07fff", null ]
+    ] ],
     [ "spa_node", "structspa__node.html", [
       [ "iface", "structspa__node.html#a898fcb8b2d37d7c42fd9c15d1f8c1ed7", null ]
     ] ],
@@ -189,7 +194,8 @@ var group__spa__node =
       [ "SPA_IO_Notify", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716a3aefc21098cbdc2b55cbbdc32629b2de", null ],
       [ "SPA_IO_Position", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716ad26051f31e62903ba07f33db72a3941e", null ],
       [ "SPA_IO_RateMatch", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716aed9fe718c56e44e01e02e6e8b31567d2", null ],
-      [ "SPA_IO_Memory", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716a41fcd276edf87cfe8eea522109de2f20", null ]
+      [ "SPA_IO_Memory", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716a41fcd276edf87cfe8eea522109de2f20", null ],
+      [ "SPA_IO_AsyncBuffers", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716a0a322192e59ba37dd713512ae020b6cb", null ]
     ] ],
     [ "spa_io_position_state", "group__spa__node.html#ga12aed5ed2a6ecb69734aa3eb7da4056b", [
       [ "SPA_IO_POSITION_STATE_STOPPED", "group__spa__node.html#gga12aed5ed2a6ecb69734aa3eb7da4056ba38a0f9a63830ad342b24e09879621165", null ],
@@ -208,6 +214,7 @@ var group__spa__node =
     [ "SPA_IO_BUFFERS_INIT", "group__spa__node.html#gae69edc800effe1c3f70e163611784a04", null ],
     [ "SPA_IO_MEMORY_INIT", "group__spa__node.html#ga6e56edfd21e88945c056adc8d17dd045", null ],
     [ "SPA_IO_CLOCK_FLAG_FREEWHEEL", "group__spa__node.html#ga421d271b07d7650f6b8018668ea771c7", null ],
+    [ "SPA_IO_CLOCK_FLAG_XRUN_RECOVER", "group__spa__node.html#ga59370627af55d7add7c558979dae2e97", null ],
     [ "SPA_IO_VIDEO_SIZE_VALID", "group__spa__node.html#ga50542c161ad0906f67b4be78ab2e71cd", null ],
     [ "SPA_IO_SEGMENT_BAR_FLAG_VALID", "group__spa__node.html#ga8a153a40c392f4d78b1dd45156b29f7c", null ],
     [ "SPA_IO_SEGMENT_VIDEO_FLAG_VALID", "group__spa__node.html#gac10fd7265f330c673c51a5719aaa6daa", null ],
@@ -230,6 +237,7 @@ var group__spa__node =
     [ "SPA_KEY_PORT_ALIAS", "group__spa__node.html#ga9537506ba9e8517d27353be72d3e82b6", null ],
     [ "SPA_KEY_PORT_MONITOR", "group__spa__node.html#gae091e85290ec8a7578f48c2b5a73affe", null ],
     [ "SPA_KEY_PORT_IGNORE_LATENCY", "group__spa__node.html#gad0584e7a902df3de92b8c2be0aa2ff53", null ],
+    [ "SPA_KEY_PORT_GROUP", "group__spa__node.html#gab9f77936cc95797ac2e2ea13a85651ef", null ],
     [ "SPA_TYPE_INTERFACE_Node", "group__spa__node.html#ga5c57b4fb1d72db0725992bd91b858dd6", null ],
     [ "SPA_VERSION_NODE", "group__spa__node.html#ga856b63143b916ed8de520b98e46a18ce", null ],
     [ "SPA_NODE_CHANGE_MASK_FLAGS", "group__spa__node.html#ga6dc4d1bbfffa9f49d18168d5a8302459", null ],
