@@ -1,5 +1,10 @@
 var NAVTREEINDEX18 =
 {
+"structpw__impl__factory__implementation.html":[8,4,3,2],
+"structpw__impl__factory__implementation.html#a99eef2345bd7b402f47ad72beb6ebfe7":[8,4,3,2,1],
+"structpw__impl__factory__implementation.html#ab63e939995687efd690f736730021e7f":[8,4,3,2,0],
+"structpw__impl__link.html":[8,4,4,2],
+"structpw__impl__link.html":[8,4,8,3],
 "structpw__impl__link__events.html":[8,4,4,1],
 "structpw__impl__link__events.html#a05b20c99f1014e62e0d032b92382f584":[8,4,4,1,5],
 "structpw__impl__link__events.html#a05c9fec1c6580f673d09e33005bca5ee":[8,4,4,1,0],
@@ -244,10 +249,5 @@ var NAVTREEINDEX18 =
 "structpw__protocol__native__message.html#ad9a08cd2b12fa38a8d222308270faf40":[8,6,3,1,3],
 "structpw__protocol__native__message.html#aef6ddaa16aeaa35b4276e3b2767268aa":[8,6,3,1,1],
 "structpw__protocol__server.html":[8,4,13,2],
-"structpw__protocol__server.html#a01d6fae5e363f6694f092256c19366ea":[8,4,13,2,3],
-"structpw__protocol__server.html#a0ac79f449a098fd48ac49f48f56a0ed3":[8,4,13,2,0],
-"structpw__protocol__server.html#a0b93bd3cd5a2680d8ece4796826406fc":[8,4,13,2,1],
-"structpw__protocol__server.html#acc7b1e9530a048b084976fc647ab446f":[8,4,13,2,4],
-"structpw__protocol__server.html#ae953d4026c613d91a0cb34398d3f4367":[8,4,13,2,2],
-"structpw__proxy.html":[8,3,13,2]
+"structpw__protocol__server.html#a01d6fae5e363f6694f092256c19366ea":[8,4,13,2,3]
 };
