@@ -1,5 +1,12 @@
 var NAVTREEINDEX21 =
 {
+"structspa__loop.html":[8,7,9,4,1],
+"structspa__loop.html#a6cd472082b361bc90f66c41b0dccea96":[8,7,9,4,1,0],
+"structspa__loop__control.html":[8,7,9,4,2],
+"structspa__loop__control.html#a392f811fbacb15de863fc0265031050f":[8,7,9,4,2,0],
+"structspa__loop__control__hooks.html":[8,7,9,4,6],
+"structspa__loop__control__hooks.html#a129526ea88e29db103f01666a32c2d20":[8,7,9,4,6,1],
+"structspa__loop__control__hooks.html#a1d60078aab0c143a082ab30e91151dd2":[8,7,9,4,6,0],
 "structspa__loop__control__hooks.html#a94545cf994d47a1acc84437e5c357141":[8,7,9,4,6,2],
 "structspa__loop__control__methods.html":[8,7,9,4,7],
 "structspa__loop__control__methods.html#a2673d98892466d81baea852c94c91a39":[8,7,9,4,7,1],
@@ -242,12 +249,5 @@ var NAVTREEINDEX21 =
 "structspa__process__latency__info.html#a1e891c0385d3fb6840019255e4a7bc7f":[8,7,7,68,0],
 "structspa__process__latency__info.html#a93fac86cdd1aca91cc5e57a5ea0340fb":[8,7,7,68,1],
 "structspa__process__latency__info.html#a97e2de30ab39d818003af3e303049801":[8,7,7,68,2],
-"structspa__ratelimit.html":[9,0,280],
-"structspa__ratelimit.html#a45159c1daa14dddd0e911cbbbac0467f":[9,0,280,4],
-"structspa__ratelimit.html#a54120e58d9dbe2d34bd6c4d217a23030":[9,0,280,0],
-"structspa__ratelimit.html#a9b0862c9c1b74066994419ce0957b43b":[9,0,280,1],
-"structspa__ratelimit.html#af29b16a4c28de3a2503ae1302dba9ff7":[9,0,280,2],
-"structspa__ratelimit.html#af383ccf1d089eadee60b0259afc329ab":[9,0,280,3],
-"structspa__rectangle.html":[8,7,8,1,1],
-"structspa__rectangle.html#a6104eab08e11a0f5f658a5ffd1878068":[8,7,8,1,1,0]
+"structspa__ratelimit.html":[9,0,280]
 };
